pub fn advance_current_pagetable(entry: &PageTableEntry) -> *mut PageTableExpand description
Returns a mutable pointer to the next page table
pub fn advance_current_pagetable(entry: &PageTableEntry) -> *mut PageTableReturns a mutable pointer to the next page table